# VPGen
Create a porous medium. Customize the domain size, origin, periodicity, and indentation. Set the number of obstacles or porosity and set the obstacles radius range. 2D and 3D possible.

Below is an example of a 2d domain with size (1, 1) and origin (0, 0). The X indent is 1.5 and has a Y periodicity.
![alt text](https://drive.google.com/uc?id=1DVnwRodpkKkxZqSzrbRM8dmikg-MOOq3)

INFO: buildLibWindow.bat must be edited to suit your system. Your Windows Kit or Visual Studio may be different from mine. I don't plan to use cmake at the moment.
